==> rasgotransforms-2.0.1a2-py3-none-any.whl: rasgotransforms/render/environment.py <==
from jinja2 import Environment
import re
from datetime import datetime
from itertools import combinations, permutations, product
from typing import Callable, Optional, Dict
from rasgotransforms.exceptions import RenderException


class RasgoEnvironment(Environment):
    def __init__(self, run_query: Callable, *args, **kwargs):
        super().__init__(*args, extensions=self.rasgo_extensions, **kwargs)
        for filter_name, method in self.rasgo_filters.items():
            self.filters[filter_name] = method
        self.globals = self.rasgo_globals
        self.globals['run_query'] = run_query

    @property
    def rasgo_extensions(self):
        return ['jinja2.ext.do', 'jinja2.ext.loopcontrols']

    @property
    def rasgo_globals(self):
        return {
            "cleanse_name": cleanse_template_symbol,
            "raise_exception": raise_exception,
            "itertools": {"combinations": combinations, "permutations": permutations, "product": product},
        }

    @property
    def rasgo_filters(self):
        return {"todatetime": datetime.fromisoformat}

    def render(
        self,
        source_code: str,
        source_table: str,
        arguments: dict,
        source_columns: Optional[Dict[str, Dict[str, str]]] = None,
        override_globals: Optional[Dict[str, Callable]] = None,
    ) -> str:
        """
        Given the source code of a jinja template, its arguments, and metadata about the source table,
        this renders the transform sql.

        Source columns can be a mapping of table names to columns (e.g. {table_name: {column_name: column_type}})
        or a function which returns a mapping of columns names to column types given a table fqtn
        (e.g. get_columns(fqtn): return {column_name: column_type}
        """
        arguments['source_table'] = source_table

        if not override_globals:
            override_globals = {}

        if source_columns and 'get_columns' not in override_globals:

            def get_columns(fqtn):
                return source_columns[fqtn]

            override_globals['get_columns'] = get_columns
        try:
            template = self.from_string(source_code)
            rendered = template.render(**arguments, **override_globals)
        except Exception as e:
            raise RenderException(e)
        return rendered


def cleanse_template_symbol(symbol: str) -> str:
    symbol = str(symbol).strip().replace(' ', '_').replace('-', '_')
    symbol = re.sub('[^A-Z0-9_]+', '', symbol)
    symbol = '_' + symbol if symbol[0].isdecimal() or not symbol else symbol
    return symbol


def raise_exception(message: str) -> None:
    raise Exception(message)

==> rasgotransforms-2.0.3-py3-none-any.whl: rasgotransforms/render/environment.py <==
from jinja2 import Environment
import re
from datetime import datetime
from itertools import combinations, permutations, product
from typing import Callable, Optional, Dict
from rasgotransforms.exceptions import RenderException


class RasgoEnvironment(Environment):
    def __init__(self, run_query: Callable, *args, **kwargs):
        super().__init__(*args, extensions=self.rasgo_extensions, **kwargs)
        for filter_name, method in self.rasgo_filters.items():
            self.filters[filter_name] = method
        for name, value in self.rasgo_globals.items():
            self.globals[name] = value
        self.globals['run_query'] = run_query

    @property
    def rasgo_extensions(self):
        return ['jinja2.ext.do', 'jinja2.ext.loopcontrols']

    @property
    def rasgo_globals(self):
        return {
            "cleanse_name": cleanse_template_symbol,
            "raise_exception": raise_exception,
            "itertools": {"combinations": combinations, "permutations": permutations, "product": product},
        }

    @property
    def rasgo_filters(self):
        return {"todatetime": datetime.fromisoformat}

    def render(
        self,
        source_code: str,
        source_table: str,
        arguments: dict,
        source_columns: Optional[Dict[str, Dict[str, str]]] = None,
        override_globals: Optional[Dict[str, Callable]] = None,
    ) -> str:
        """
        Given the source code of a jinja template, its arguments, and metadata about the source table,
        this renders the transform sql.

        Source columns can is a mapping of table names to columns (e.g. {table_name: {column_name: column_type}})
        """
        arguments['source_table'] = source_table

        if not override_globals:
            override_globals = {}

        if source_columns and 'get_columns' not in override_globals:

            def get_columns(fqtn):
                return source_columns[fqtn]

            override_globals['get_columns'] = get_columns
        try:
            template = self.from_string(source_code)
            rendered = template.render(**arguments, **override_globals)
        except Exception as e:
            raise RenderException(e)
        return rendered


def cleanse_template_symbol(symbol: str) -> str:
    symbol = str(symbol).strip().replace(' ', '_').replace('-', '_')
    symbol = re.sub('[^A-Z0-9_]+', '', symbol)
    symbol = '_' + symbol if not symbol or symbol[0].isdecimal() else symbol
    return symbol


def raise_exception(message: str) -> None:
    raise Exception(message)
